# ssnapshot

## What is it

ssnapshot is a utility to produce summaries of the current state of a slurm cluster.

## Main features

## Where to get it

## Dependencies

## Installation from sources

## License



